@@ -1,4 +1,6 @@
 /*
+ *  arch-tag: Implementation of various Rhythmbox utility functions for URIs and files
+ *
  *  Copyright (C) 2002 Jorn Baayen
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -15,7 +17,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rb-file-helpers.c,v 1.18 2003/08/11 00:43:25 cwalters Exp $
  */
 
 #include <gtk/gtk.h>
@@ -49,6 +50,7 @@ rb_file (const char *filename)
 		SHARE_DIR "/",
 		SHARE_DIR "/glade/",
 		SHARE_DIR "/art/",
+		SHARE_DIR "/views/",
 		SHARE_DIR "/node-views/",
 		SHARE_UNINSTALLED_DIR "/",
 		SHARE_UNINSTALLED_DIR "/glade/",
@@ -135,10 +137,19 @@ rb_uri_resolve_symlink (const char *uri)
 	gnome_vfs_get_file_info (uri, info,
 				 GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE);
 
-	if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK)
-		real = g_strdup (info->symlink_name);
-	else
+	if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK) {
+		GnomeVFSURI *vfsuri;
+		GnomeVFSURI *new_vfsuri;
+
+		vfsuri = gnome_vfs_uri_new (uri);
+		new_vfsuri = gnome_vfs_uri_resolve_relative (vfsuri, info->symlink_name);
+		real = gnome_vfs_uri_to_string (new_vfsuri, GNOME_VFS_URI_HIDE_NONE); 
+
+		gnome_vfs_uri_unref (new_vfsuri);
+		gnome_vfs_uri_unref (vfsuri);
+	} else {
 		real = g_strdup (uri);
+	}
 
 	gnome_vfs_file_info_unref (info);
 
@@ -606,7 +617,6 @@ rb_uri_is_iradio (const char *uri)
 void
 rb_uri_handle_recursively (const char *text_uri,
 		           GFunc func,
-			   GMutex *cancel_lock,
 			   gboolean *cancelflag,
 		           gpointer user_data)
 {
@@ -627,14 +637,8 @@ rb_uri_handle_recursively (const char *text_uri,
 		GnomeVFSURI *file_uri;
 		char *file_uri_text;
 
-		if (cancel_lock) {
-			g_mutex_lock (cancel_lock);
-			if (*cancelflag) {
-				g_mutex_unlock (cancel_lock);
-				break;
-			}
-			g_mutex_unlock (cancel_lock);
-		}
+		if (cancelflag && *cancelflag)
+			break;
 
 		info = (GnomeVFSFileInfo *) l->data;
 		
@@ -648,11 +652,11 @@ rb_uri_handle_recursively (const char *text_uri,
 		if (info->type != GNOME_VFS_FILE_TYPE_REGULAR)
 		{
 			if ((info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) &&
-			    (info->name) && (info->name[0] != '.'))
+			    (info->name) && (strcmp (info->name, "."))
+			    && (strcmp (info->name, "..")))
 			{
 				rb_uri_handle_recursively (file_uri_text,
 							   func,
-							   cancel_lock,
 							   cancelflag,
 							   user_data);
 
