@@ -110,6 +110,7 @@ rb_shuffle_play_order_new (RBShellPlayer *player)
 static void
 rb_shuffle_play_order_class_init (RBShufflePlayOrderClass *klass)
 {
+	RBPlayOrderClass *porder;
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
@@ -117,7 +118,7 @@ rb_shuffle_play_order_class_init (RBShufflePlayOrderClass *klass)
 	object_class->constructor = rb_shuffle_play_order_constructor;
 	object_class->finalize = rb_shuffle_play_order_finalize;
 
-	RBPlayOrderClass *porder = RB_PLAY_ORDER_CLASS (klass);
+	porder = RB_PLAY_ORDER_CLASS (klass);
 	porder->get_next = rb_shuffle_play_order_get_next;
 	porder->go_next = rb_shuffle_play_order_go_next;
 	porder->get_previous = rb_shuffle_play_order_get_previous;
